# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v1.1.1

### Chores

- Add credits in readme (@userlerueda)

## v1.1.0

### Changed

- Move to new API url to be consistent with web application (@userlerueda)

## v1.0.0

### Removed

- Removed CCP functionality which has now been moved to a different [package](https://github.com/userlerueda/ccp) (@userlerueda)

### Fixed

- Fixes missing json import in classes.py (@userlurueda)

## v0.1.0

### Added

- Adds option to post results (@userlerueda)
- Adds option to get club results (@userlerueda)
